Enum style::values::computed::length::LengthOrPercentage
[−]
[src]
pub enum LengthOrPercentage {
Length(Length),
Percentage(Percentage),
Calc(CalcLengthOrPercentage),
}Variants
Length(Length)Percentage(Percentage)Calc(CalcLengthOrPercentage)
Methods
impl LengthOrPercentage[src]
pub fn zero() -> LengthOrPercentage[src]
pub fn one() -> LengthOrPercentage[src]
1px length value for SVG defaults
pub fn is_definitely_zero(&self) -> bool[src]
Returns true if the computed value is absolute 0 or 0%.
(Returns false for calc() values, even if ones that may resolve to zero.)
pub fn to_hash_key(&self) -> (Au, NotNaN<f32>)[src]
pub fn to_used_value(&self, containing_length: Au) -> Au[src]
Returns the used value.
pub fn to_pixel_length(&self, containing_length: Au) -> Length[src]
Returns the used value as CSSPixelLength.
pub fn clamp_to_non_negative(self) -> Self[src]
Returns the clamped non-negative values.