Struct style::values::computed::length::CalcLengthOrPercentage
[−]
[src]
pub struct CalcLengthOrPercentage {
pub clamping_mode: AllowedNumericType,
pub percentage: Option<Percentage>,
// some fields omitted
}Fields
clamping_mode: AllowedNumericType
percentage: Option<Percentage>
Methods
impl CalcLengthOrPercentage[src]
pub fn new(length: Length, percentage: Option<Percentage>) -> Self[src]
Returns a new CalcLengthOrPercentage.
pub fn with_clamping_mode(
length: Length,
percentage: Option<Percentage>,
clamping_mode: AllowedNumericType
) -> Self[src]
length: Length,
percentage: Option<Percentage>,
clamping_mode: AllowedNumericType
) -> Self
Returns a new CalcLengthOrPercentage with a specific clamping mode.
pub fn length(&self) -> CSSPixelLength[src]
Returns this calc() as a <length>.
Panics in debug mode if a percentage is present in the expression.
pub fn length_component(&self) -> CSSPixelLength[src]
Returns the length component of this calc()
pub fn unclamped_length(&self) -> CSSPixelLength[src]
Returns the <length> component of this calc(), unclamped.
pub fn percentage(&self) -> CSSFloat[src]
Return the percentage value as CSSFloat.
pub fn to_used_value(&self, container_len: Option<Au>) -> Option<Au>[src]
Convert the computed value into used value.
pub fn to_pixel_length(&self, container_len: Option<Au>) -> Option<Length>[src]
If there are special rules for computing percentages in a value (e.g. the height property), they apply whenever a calc() expression contains percentages.