Type Definition style::values::computed::length::NonNegativeLength
[−]
[src]
type NonNegativeLength = NonNegative<Length>;
A wrapper of Length, whose value must be >= 0.
Methods
impl NonNegativeLength[src]
pub fn new(px: CSSFloat) -> Self[src]
Create a NonNegativeLength.
pub fn zero() -> Self[src]
Return a zero value.
pub fn px(&self) -> CSSFloat[src]
Return the pixel value of |NonNegativeLength|.
pub fn clamp(self) -> Self[src]
Ensures it is non negative
pub fn scale_by(&self, factor: f32) -> Self[src]
Scale this NonNegativeLength. We scale NonNegativeLength by zero if the factor is negative because it doesn't make sense to scale a negative factor on a non-negative length.